@@ -1,7 +1,13 @@
+import sys
+import pytest
 from vispy import scene
 from ..axes import AxesVisual3D
 
+IS_WIN = sys.platform == 'win32'
+PY_LT_39 = sys.version_info[:2] < (3, 9)
 
+
+@pytest.mark.skipif('PY_LT_39 and IS_WIN', reason="glBindFramebuffer has no attribute '_native'")
 def test_3d_axis_visual():
 
     canvas = scene.SceneCanvas(keys=None, size=(800, 600), show=True)
