@@ -1,4 +1,6 @@
 import numpy as np
+import pytest
+import sys
 
 from glue.core import DataCollection, Data
 from glue.app.qt.application import GlueApplication
@@ -8,6 +10,8 @@ from matplotlib import cm
 
 from ..scatter_viewer import VispyScatterViewer
 
+IS_WIN = sys.platform == 'win32'
+
 
 def make_test_data():
 
@@ -22,6 +26,7 @@ def make_test_data():
     return data
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_scatter_viewer(tmpdir):
 
     # Create fake data
@@ -122,6 +127,7 @@ def test_scatter_viewer(tmpdir):
     ga2.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_error_bars(tmpdir):
 
     # Create fake data
@@ -184,6 +190,7 @@ def test_error_bars(tmpdir):
     ga2.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_vectors(tmpdir):
 
     # Create fake data
@@ -248,6 +255,7 @@ def test_vectors(tmpdir):
     ga2.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_n_dimensional_data():
 
     # Create fake data
@@ -277,6 +285,7 @@ def test_n_dimensional_data():
     ga.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_scatter_remove_layer_artists(tmpdir):
 
     # Regression test for a bug that caused layer states to not be removed
@@ -320,6 +329,7 @@ def test_scatter_remove_layer_artists(tmpdir):
     ga2.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_add_data_with_incompatible_subsets(tmpdir):
 
     # Regression test for a bug that an error when adding a dataset with an
@@ -342,6 +352,7 @@ def test_add_data_with_incompatible_subsets(tmpdir):
     ga.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_not_all_points_inside_limits(tmpdir):
 
     # Regression test for a bug that occurred when not all points were inside
@@ -365,6 +376,7 @@ def test_not_all_points_inside_limits(tmpdir):
     ga.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_categorical_color_size(tmpdir):
 
     # Create fake data
@@ -397,6 +409,7 @@ def test_categorical_color_size(tmpdir):
     ga.close()
 
 
+@pytest.mark.skipif('IS_WIN', reason='Windows fatal exception: access violation')
 def test_layer_visibility_after_session(tmpdir):
 
     # Regression test for a bug that caused layers to be incorrectly visible
